@@ -78,6 +78,8 @@ static QString quoteForParam( const QString &text )
 {
   QString tmp = text;
   tmp.remove( '"' );
+  if ( tmp.contains( ';' ) || tmp.contains( ':' ) || tmp.contains( ',' ) )
+    return tmp; // libical quotes in this case already, see icalparameter_as_ical_string()
   return QString::fromLatin1( "\"" ) + tmp + QString::fromLatin1( "\"" );
 }
 
@@ -580,8 +582,10 @@ void ICalFormatImpl::Private::writeIncidenceBase( icalcomponent *parent,
 
   // organizer stuff
   if ( !incidenceBase->organizer().isEmpty() ) {
-    icalcomponent_add_property(
-      parent, mImpl->writeOrganizer( incidenceBase->organizer() ) );
+    icalproperty *p = mImpl->writeOrganizer( incidenceBase->organizer() );
+    if ( p ) {
+      icalcomponent_add_property( parent, p );
+    }
   }
 
   // attendees
@@ -589,7 +593,10 @@ void ICalFormatImpl::Private::writeIncidenceBase( icalcomponent *parent,
     Attendee::List::ConstIterator it;
     for ( it = incidenceBase->attendees().constBegin();
           it != incidenceBase->attendees().constEnd(); ++it ) {
-      icalcomponent_add_property( parent, mImpl->writeAttendee( *it ) );
+      icalproperty *p = mImpl->writeAttendee( *it );
+      if ( p ) {
+        icalcomponent_add_property( parent, p );
+      }
     }
   }
 
@@ -608,7 +615,18 @@ void ICalFormatImpl::Private::writeCustomProperties( icalcomponent *parent,
 {
   const QMap<QByteArray, QString> custom = properties->customProperties();
   for ( QMap<QByteArray, QString>::ConstIterator c = custom.begin();  c != custom.end();  ++c ) {
+
     icalproperty *p = icalproperty_new_x( c.value().toUtf8() );
+    if ( !c.key().startsWith( "X-KDE" ) &&          //krazy:exclude=strings
+         !c.key().startsWith( "X-LibKCal" ) &&      //krazy:exclude=strings
+         !c.key().startsWith( "X-MICROSOFT" ) &&    //krazy:exclude=strings
+         !c.key().startsWith( "X-MOZILLA" ) &&      //krazy:exclude=strings
+         !c.key().startsWith( "X-PILOT" ) ) {       //krazy:exclude=strings
+      // use text values for the typical X-FOO property.
+      // except for vendor specific X-FOO properties.
+      icalvalue *text = icalvalue_new_text( c.value().toUtf8().data() );
+      icalproperty_set_value( p, text );
+    }
     icalproperty_set_x_name( p, c.key() );
     icalcomponent_add_property( parent, p );
   }
@@ -617,8 +635,11 @@ void ICalFormatImpl::Private::writeCustomProperties( icalcomponent *parent,
 
 icalproperty *ICalFormatImpl::writeOrganizer( const Person &organizer )
 {
-  icalproperty *p =
-    icalproperty_new_organizer( "MAILTO:" + organizer.email().toUtf8() );
+  if ( organizer.email().isEmpty() ) {
+    return 0;
+  }
+
+  icalproperty *p = icalproperty_new_organizer( "MAILTO:" + organizer.email().toUtf8() );
 
   if ( !organizer.name().isEmpty() ) {
     icalproperty_add_parameter(
@@ -658,6 +679,10 @@ icalproperty *ICalFormatImpl::writeLocation( const QString &location, bool isRic
 
 icalproperty *ICalFormatImpl::writeAttendee( Attendee *attendee )
 {
+  if ( attendee->email().isEmpty() ) {
+    return 0;
+  }
+
   icalproperty *p =
     icalproperty_new_attendee( "mailto:" + attendee->email().toUtf8() );
 
@@ -937,13 +962,14 @@ icalcomponent *ICalFormatImpl::writeAlarm( Alarm *alarm )
     const QList<Person> addresses = alarm->mailAddresses();
     for ( QList<Person>::ConstIterator ad = addresses.constBegin();
           ad != addresses.constEnd();  ++ad ) {
-      icalproperty *p = icalproperty_new_attendee(
-        "MAILTO:" + (*ad).email().toUtf8() );
-      if ( !(*ad).name().isEmpty() ) {
-        icalproperty_add_parameter(
-          p, icalparameter_new_cn( quoteForParam( (*ad).name() ).toUtf8() ) );
+      if ( !(*ad).email().isEmpty() ) {
+        icalproperty *p = icalproperty_new_attendee( "MAILTO:" + (*ad).email().toUtf8() );
+        if ( !(*ad).name().isEmpty() ) {
+          icalproperty_add_parameter(
+            p, icalparameter_new_cn( quoteForParam( (*ad).name() ).toUtf8() ) );
+        }
+        icalcomponent_add_property( a, p );
       }
-      icalcomponent_add_property( a, p );
     }
     icalcomponent_add_property(
       a, icalproperty_new_summary( alarm->mailSubject().toUtf8() ) );
