@@ -142,13 +142,13 @@ bool ResourceLocalDir::doLoad( bool )
   const QStringList entries = dir.entryList( QDir::Files | QDir::Readable );
 
   bool success = true;
-  QStringList::ConstIterator it;
-  for ( it = entries.begin(); it != entries.end(); ++it ) {
-    if ( (*it).endsWith( '~' ) ) { // is backup file, ignore it
-      continue;
+  for ( int i = 0, count = entries.count(); i < count; ++i ) {
+    if ( entries[i].contains( QRegExp( "(~|\\.new|\\.tmp)$" ) ) ||
+         entries[i].startsWith( d->mURL.path() + "/qt_temp." ) ) {
+      continue;  // backup or temporary file, ignore it
     }
 
-    const QString fileName = dirName + '/' + *it;
+    const QString fileName = dirName + '/' + entries[i];
     kDebug() << " read '" << fileName << "'";
     CalendarLocal cal( calendar()->timeSpec() );
     if ( !doFileLoad( cal, fileName ) ) {
@@ -195,6 +195,11 @@ bool ResourceLocalDir::doSave( bool syncCache )
 
 bool ResourceLocalDir::doSave( bool, Incidence *incidence )
 {
+  if ( d->mDeletedIncidences.contains( incidence ) ) {
+    d->mDeletedIncidences.removeAll( incidence );
+    return true;
+  }
+
   d->mDirWatch.stopScan();  // do prohibit the dirty() signal and a following reload()
 
   QString fileName = d->mURL.path() + '/' + incidence->uid();
@@ -218,7 +223,9 @@ void ResourceLocalDir::reload( const QString &file )
 {
   kDebug();
 
-  if ( !isOpen() ) {
+  if ( !isOpen() ||
+       file.contains( QRegExp( "(~|\\.new|\\.tmp)$" ) ) ||
+       file.startsWith( d->mURL.path() + "/qt_temp." ) ) {
     return;
   }
 
@@ -234,7 +241,12 @@ bool ResourceLocalDir::deleteEvent( Event *event )
 {
   kDebug();
   if ( d->deleteIncidenceFile( event ) ) {
-    return calendar()->deleteEvent( event );
+    if ( calendar()->deleteEvent( event ) ) {
+      d->mDeletedIncidences.append( event );
+      return true;
+    } else {
+      return false;
+    }
   } else {
     return false;
   }
@@ -248,7 +260,12 @@ void ResourceLocalDir::deleteAllEvents()
 bool ResourceLocalDir::deleteTodo( Todo *todo )
 {
   if ( d->deleteIncidenceFile( todo ) ) {
-    return calendar()->deleteTodo( todo );
+    if ( calendar()->deleteTodo( todo ) ) {
+      d->mDeletedIncidences.append( todo );
+      return true;
+    } else {
+      return false;
+    }
   } else {
     return false;
   }
@@ -262,7 +279,12 @@ void ResourceLocalDir::deleteAllTodos()
 bool ResourceLocalDir::deleteJournal( Journal *journal )
 {
   if ( d->deleteIncidenceFile( journal ) ) {
-    return calendar()->deleteJournal( journal );
+    if ( calendar()->deleteJournal( journal ) ) {
+      d->mDeletedIncidences.append( journal );
+      return true;
+    } else {
+      return false;
+    }
   } else {
     return false;
   }
